@@ -19,18 +19,17 @@ access_types <- c("exists" = 0L, "read" = 4L, "write" = 2L, "execute" = 1L)
 #' file_exists("WOMBATS")
 file_access <- function(path, mode = "exists") {
   assert_no_missing(path)
-
-  path <- path_expand(path)
   mode <- match.arg(mode, names(access_types), several.ok = TRUE)
+
+  old <- path_expand(path)
   mode <- sum(access_types[mode])
 
-  access_(unclass(path), mode)
+  access_(unclass(old), mode)
 }
 
 #' @rdname file_access
 #' @export
 file_exists <- function(path) {
-  path <- path_expand(path)
   res <- file_info(path)
   setNames(!is.na(res$type), res$path)
 }
@@ -38,7 +37,6 @@ file_exists <- function(path) {
 #' @rdname file_access
 #' @export
 dir_exists <- function(path) {
-  path <- path_expand(path)
   res <- is_dir(path)
   !is.na(res) & res
 }
@@ -46,7 +44,6 @@ dir_exists <- function(path) {
 #' @rdname file_access
 #' @export
 link_exists <- function(path) {
-  path <- path_expand(path)
   res <- is_link(path)
   !is.na(res) & res
 }
